Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1039)

Unified Diff: third_party/WebKit/Source/core/workers/WorkerLoaderProxy.h

Issue 2715803004: Introduce ThreadableLoadingContext: make threaded loading code one step away from Document (Closed)
Patch Set: . Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/workers/WorkerLoaderProxy.h
diff --git a/third_party/WebKit/Source/core/workers/WorkerLoaderProxy.h b/third_party/WebKit/Source/core/workers/WorkerLoaderProxy.h
index c2235f0231870ca8c6f6b719ee802ed97f45d0d3..323ff01d6f3be789effb3b972350423612c7eb34 100644
--- a/third_party/WebKit/Source/core/workers/WorkerLoaderProxy.h
+++ b/third_party/WebKit/Source/core/workers/WorkerLoaderProxy.h
@@ -41,7 +41,7 @@
namespace blink {
-class ExecutionContext;
+class ThreadableLoadingContext;
// The WorkerLoaderProxy is a proxy to the loader context. Normally, the
// document on the main thread provides loading services for the subordinate
@@ -77,8 +77,8 @@ class CORE_EXPORT WorkerLoaderProxyProvider {
std::unique_ptr<WTF::CrossThreadClosure>) = 0;
// It is guaranteed that this gets accessed only on the thread where
- // the ExecutionContext is bound.
- virtual ExecutionContext* getLoaderExecutionContext() = 0;
+ // the loading context is bound.
+ virtual ThreadableLoadingContext* getThreadableLoadingContext() = 0;
};
class CORE_EXPORT WorkerLoaderProxy final
@@ -101,8 +101,8 @@ class CORE_EXPORT WorkerLoaderProxy final
// This may return nullptr.
// This must be called from the main thread (== the thread of the
- // loader execution context).
- ExecutionContext* getLoaderExecutionContext();
+ // loading context).
+ ThreadableLoadingContext* getThreadableLoadingContext();
// Notification from the provider that it can no longer be accessed. An
// implementation of WorkerLoaderProxyProvider is required to call

Powered by Google App Engine
This is Rietveld 408576698